==> Paws-0.24.tar.gz: Paws-0.24/lib/Paws/KMS/DisableKey.pm <==

package Paws::KMS::DisableKey;
  use Moose;
  has KeyId => (is => 'ro', isa => 'Str', required => 1);

  use MooseX::ClassAttribute;

  class_has _api_call => (isa => 'Str', is => 'ro', default => 'DisableKey');
  class_has _returns => (isa => 'Str', is => 'ro');
  class_has _result_key => (isa => 'Str', is => 'ro');
1;

### main pod documentation begin ###

=head1 NAME

Paws::KMS::DisableKey - Arguments for method DisableKey on Paws::KMS

=head1 DESCRIPTION

This class represents the parameters used for calling the method DisableKey on the 
AWS Key Management Service service. Use the attributes of this class
as arguments to method DisableKey.

You shouldn't make instances of this class. Each attribute should be used as a named argument in the call to DisableKey.

As an example:

  $service_obj->DisableKey(Att1 => $value1, Att2 => $value2, ...);

Values for attributes that are native types (Int, String, Float, etc) can passed as-is (scalar values). Values for complex Types (objects) can be passed as a HashRef. The keys and values of the hashref will be used to instance the underlying object.

=head1 ATTRIBUTES


=head2 B<REQUIRED> KeyId => Str

A unique identifier for the customer master key. This value can be a
globally unique identifier or the fully specified ARN to a key.

=over

=item * Key ARN Example -
arn:aws:kms:us-east-1:123456789012:key/12345678-1234-1234-1234-123456789012

=item * Globally Unique Key ID Example -
12345678-1234-1234-1234-123456789012

=back





=head1 SEE ALSO

This class forms part of L<Paws>, documenting arguments for method DisableKey in L<Paws::KMS>

=head1 BUGS and CONTRIBUTIONS

The source code is located here: https://github.com/pplu/aws-sdk-perl

Please report bugs to: https://github.com/pplu/aws-sdk-perl/issues

=cut

==> Paws-0.28.tar.gz: Paws-0.28/lib/Paws/KMS/DisableKey.pm <==

package Paws::KMS::DisableKey;
  use Moose;
  has KeyId => (is => 'ro', isa => 'Str', required => 1);

  use MooseX::ClassAttribute;

  class_has _api_call => (isa => 'Str', is => 'ro', default => 'DisableKey');
  class_has _returns => (isa => 'Str', is => 'ro');
  class_has _result_key => (isa => 'Str', is => 'ro');
1;

### main pod documentation begin ###

=head1 NAME

Paws::KMS::DisableKey - Arguments for method DisableKey on Paws::KMS

=head1 DESCRIPTION

This class represents the parameters used for calling the method DisableKey on the 
AWS Key Management Service service. Use the attributes of this class
as arguments to method DisableKey.

You shouldn't make instances of this class. Each attribute should be used as a named argument in the call to DisableKey.

As an example:

  $service_obj->DisableKey(Att1 => $value1, Att2 => $value2, ...);

Values for attributes that are native types (Int, String, Float, etc) can passed as-is (scalar values). Values for complex Types (objects) can be passed as a HashRef. The keys and values of the hashref will be used to instance the underlying object.

=head1 ATTRIBUTES


=head2 B<REQUIRED> KeyId => Str

A unique identifier for the CMK.

Use the CMK's unique identifier or its Amazon Resource Name (ARN). For
example:

=over

=item *

Unique ID: 1234abcd-12ab-34cd-56ef-1234567890ab

=item *

ARN:
arn:aws:kms:us-west-2:111122223333:key/1234abcd-12ab-34cd-56ef-1234567890ab

=back





=head1 SEE ALSO

This class forms part of L<Paws>, documenting arguments for method DisableKey in L<Paws::KMS>

=head1 BUGS and CONTRIBUTIONS

The source code is located here: https://github.com/pplu/aws-sdk-perl

Please report bugs to: https://github.com/pplu/aws-sdk-perl/issues

=cut
